package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.BlineevalMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IBlineeval;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.ExcelUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.PoiExcelUtils;
import com.datacloudsec.utils.ReflectUtils;
import com.datacloudsec.utils.SystemUtil;
import java.io.File;
import java.io.FileOutputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.fileupload.FileItem;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.FilenameUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Workbook;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/BlineevalService.class */
public class BlineevalService implements IBlineeval {
    private Logger LOG = Logger.getLogger(BlineevalService.class);
    private BlineevalMapper blineevalMapper = (BlineevalMapper) InstanceUtil.newDaoInstance(BlineevalMapper.class);
    private IEngine engineService = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);

    public int searchCount(HttpSession session, String name, Integer level, String name_cn, String family_cn, String type) throws Exception {
        return this.blineevalMapper.searchCount(name, level, name_cn, family_cn, DataRule.getRuleWhere(session, "t_bline_policies"), type);
    }

    public List<Map<String, Object>> search(HttpSession session, String name, Integer level, String name_cn, String family_cn, String type, Integer offset, Integer limit) throws Exception {
        return this.blineevalMapper.search(name, level, name_cn, family_cn, offset, limit, DataRule.getRuleWhere(session, "t_bline_policies"), type);
    }

    public List<String> blineGroup() throws Exception {
        return this.blineevalMapper.blineGroup();
    }

    public Map<String, Object> getBlineById(HttpSession session, String poliid) throws Exception {
        return this.blineevalMapper.getBlineById(poliid, DataRule.getRuleWhere(session, "t_bline_policies"), (String) null);
    }

    public List<Map<String, Object>> blineTempGroup(String name_cn, String family_cn, String type, Integer offset, Integer limit) {
        return this.blineevalMapper.blineTempGroup(name_cn, family_cn, type, offset, limit);
    }

    public Integer blinetmpCount(String name_cn, String family_cn, String type) throws Exception {
        return this.blineevalMapper.blinetmpCount(name_cn, family_cn, type);
    }

    public void onOff(String poliid, String name_cn, Boolean flag) throws Exception {
        if (StringUtils.isNotBlank(poliid)) {
            this.blineevalMapper.onOffById(flag.booleanValue() ? null : ReportService.REPORT_STATE_SUCCESS, poliid);
        } else if (StringUtils.isNotBlank(name_cn)) {
            this.blineevalMapper.onOffByNameCN(flag.booleanValue() ? null : ReportService.REPORT_STATE_SUCCESS, name_cn);
        } else {
            this.blineevalMapper.onOffByAll(flag.booleanValue() ? null : ReportService.REPORT_STATE_SUCCESS);
        }
    }

    public void setLevel(Integer level, String poliid) throws Exception {
        this.blineevalMapper.setLevel(level, poliid);
    }

    public List<Map<String, Object>> getFamilies() throws Exception {
        return this.blineevalMapper.getFamilies();
    }

    public List<Map<String, Object>> getTypes() throws Exception {
        return this.blineevalMapper.getTypes();
    }

    public void insertPolicy(HttpSession session, String name, String name_cn, String family, String family_cn, String poliname, Integer level, String checkingPoint, String checkitem, String type, String desct, String advice, String defaults, String command, String conform, String regex) throws Exception {
        Map<String, Object> options = new HashMap<>();
        options.put("assetType", family);
        options.put("linuxV", poliname);
        options.put("default", defaults);
        options.put("command", command);
        options.put("conform", conform);
        options.put("regex", regex);
        Map<String, Object> result = this.engineService.addBlinePolicy(options);
        if (result == null || StringUtils.isBlank(ObjectUtil.getString(result.get("policyid"), (String) null))) {
            this.LOG.error("策略添加失败，引擎未返回策略ID");
            throw new UEException("策略添加失败");
        }
        try {
            User user = (User) session.getAttribute("userInfo");
            this.blineevalMapper.insertPolicy(ObjectUtil.getString(result.get("policyid"), ""), name, name_cn, family, family_cn, poliname, level, checkingPoint, checkitem, type, desct, advice, defaults, command, conform, regex, user.getId());
        } catch (Exception e) {
            delPolicy(session, ObjectUtil.getString(result.get("policyid"), ""));
            throw e;
        }
    }

    public void updatePolicy(HttpSession session, String poliid, String name, Integer level, String checkingPoint, String checkitem, String desct, String advice, String defaults, String command, String conform, String regex) throws Exception {
        Map<String, Object> policy = this.blineevalMapper.getBlineById(poliid, DataRule.getRuleWhere(session, "t_bline_policies"), (String) null);
        if (policy == null) {
            throw new UEException("策略不存在");
        }
        Map<String, Object> options = new HashMap<>();
        options.put("assetType", ObjectUtil.getString(policy.get("family"), ""));
        options.put("linuxV", ObjectUtil.getString(policy.get("poliname"), ""));
        options.put("default", defaults);
        options.put("command", command);
        options.put("conform", conform);
        options.put("regex", regex);
        this.engineService.updBlinePolicy(options, poliid);
        User user = (User) session.getAttribute("userInfo");
        this.blineevalMapper.updatePolicy(poliid, name, level, checkingPoint, checkitem, desct, advice, defaults, command, conform, regex, user.getId());
    }

    public void delPolicy(HttpSession session, String poliid) throws Exception {
        this.engineService.delBlinePolicy(poliid);
        this.blineevalMapper.delPolicy(poliid, DataRule.getRuleWhere(session, "t_bline_policies"));
    }

    public void impPolicy(HttpSession session, FileItem file) throws Exception {
        File f = SystemUtil.uploadFile(file, Constant.TEMP_DIR, String.valueOf(System.nanoTime()) + "." + FilenameUtils.getExtension(file.getName()));
        ExcelUtil excelUtil = new ExcelUtil();
        Workbook workbook = excelUtil.getWorkbook(f);
        List<String[]> policies = excelUtil.readXlsx(workbook.getSheetAt(0), 2, 13, (Integer) null, new int[]{0, 1, 2, 3, 6, 9, 10, 11, 12});
        Map<String, String> family = new HashMap<>();
        family.put("国产操作系统", "cos");
        family.put("数据库", "db");
        family.put("虚拟化平台", "hypervisor");
        family.put("Linux", "linux");
        family.put("中间件", "middleware");
        family.put("安全设备", "netsec");
        family.put("网络设备", "netsec");
        family.put("路由_无线", "router");
        family.put("UNIX", "unix");
        family.put("Windows", "windows");
        Map<String, String> types = new HashMap<>();
        types.put("Linux_Centos", "centos");
        types.put("Linux_Debian", "debian");
        types.put("Linux_Feodra", "feodra");
        types.put("Linux_OpenSuSE", "opensuse");
        types.put("Linux_Redhat", "redhat");
        types.put("Linux_Suse", "suse");
        types.put("Linux_Ubuntu", "ubuntu");
        types.put("Linux_其他linux发行版本", "other");
        types.put("UNIX_AIX(IBM)", "aix");
        types.put("UNIX_HP_UX(惠普)", "hpux");
        types.put("UNIX_Solaris(Oracle甲骨文)", "solaris");
        types.put("Windows_Windows", "windows");
        types.put("中间件_Apache(linux)", "apache_linux");
        types.put("中间件_Apache(Windows)", "apache_windows");
        types.put("中间件_Bind(Windows)", "bind_windows");
        types.put("中间件_IIS6(Windows)", "iis6_windows");
        types.put("中间件_IS7(Windows)", "iis7_windows");
        types.put("中间件_JBoss4(linux)", "jboss4_linux");
        types.put("中间件_Jboss4(Windows)", "jboss4_windows");
        types.put("中间件_JBoss5(linux)", "jboss5_linux");
        types.put("中间件_Jboss5(Windows)", "jboss5_windows");
        types.put("中间件_JBoss6(linux)", "jboss6_linux");
        types.put("中间件_Jboss6(Windows)", "jboss6_windows");
        types.put("中间件_Nginx(Windows)", "nginx_windows");
        types.put("中间件_Ngnix(linux)", "nginx_linux");
        types.put("中间件_Resin(linux)", "resin_linux");
        types.put("中间件_Resin(Windows)", "resin_windows");
        types.put("中间件_Tomcat(linux)", "tomcat_linux");
        types.put("中间件_Tomcat(Windows)", "tomcat_windows");
        types.put("中间件_Tongweb4.6(Linux)", "tongweb46_linux");
        types.put("中间件_Tongweb5.0(Linux)", "tongweb50_linux");
        types.put("中间件_Tongweb5.0(Windows)", "tongweb50_windows");
        types.put("中间件_Weblogic(linux)", "weblogic_linux");
        types.put("中间件_Weblogic(Windows)", "weblogic_windows");
        types.put("中间件_WebSphere(linux)", "websphere_linux");
        types.put("中间件_Websphere(Windows)", "websphere_windows");
        types.put("国产操作系统_中标麒麟", "neokylin");
        types.put("国产操作系统_深度", "deepin");
        types.put("国产操作系统_红旗", "redflag");
        types.put("安全设备_Fortigate防火墙", "fortigate_firewall");
        types.put("安全设备_Juniper防火墙", "juniper_firewall");
        types.put("安全设备_NetScreen防火墙", "netscreen_firewall");
        types.put("安全设备_主机监控系统", "asy_sa");
        types.put("安全设备_入侵防御系统", "asy_ips");
        types.put("安全设备_华三防火墙", "h3c_firewall");
        types.put("安全设备_华为防火墙", "huawei_firewall");
        types.put("安全设备_启明(天清汉马)", "venus_firewall");
        types.put("安全设备_天融信防火墙", "topsec_firewall");
        types.put("安全设备_山石防火墙", "hillstone_firewall");
        types.put("安全设备_思科防火墙", "cisco_firewall");
        types.put("安全设备_深信服", "sxf_firewall");
        types.put("安全设备_漏扫系统", "asy_scan");
        types.put("安全设备_网御星云", "leadsec_firewall");
        types.put("安全设备_网神防火墙", "legendsec_firewall");
        types.put("安全设备_风云防火墙", "fengyun_firewall");
        types.put("数据库_DB2", "DB2");
        types.put("数据库_Informix", "Informix");
        types.put("数据库_Mysql", "Mysql");
        types.put("数据库_Oracle", "Oracle");
        types.put("数据库_SqlServer", "SqlServer");
        types.put("数据库_Sybase", "Sybase");
        types.put("数据库_达梦", "DM");
        types.put("网络设备_Cisco交换机", "cisco_switch");
        types.put("网络设备_JUNIPER路由器", "juniper_route");
        types.put("网络设备_中兴交换机", "zte_switch");
        types.put("网络设备_力腾交换机", "ftos_switch");
        types.put("网络设备_华三交换机", "h3c_switch");
        types.put("网络设备_华为交换机", "huawei_switch");
        types.put("网络设备_锐捷交换机", "ruijie_switch");
        types.put("虚拟化平台_ESXi(VMWare)", "vmware_esxi");
        types.put("虚拟化平台_XenServer", "xenserver");
        types.put("路由(无线)_思科", "cisco");
        for (String[] policy : policies) {
            insertPolicy(session, policy[0], policy[2], family.get(policy[1]), policy[1].replace("路由_无线", "（路由）无线"), types.get(policy[2]), ObjectUtil.getInt(policy[6].replaceAll("[^0-9]", "")), policy[5], policy[5], policy[3], policy[7], policy[8], policy[10], policy[9], policy[12], policy[11]);
        }
    }

    public File expPolicy(String name_cn, HttpSession session) throws Exception {
        String[] headers = {"策略名称@name@8000", "所属分组@family_cn@5000", "策略类型@name_cn@8000", "模板类型@type@4000", "检查项数据@checkitem@4000", "检查点@checkingPoint@5000", "权重@level@4000", "描述@desct@10000", "建议@advice@10000", "执行命令@command@8000", "默认值@defaults@3000", "判断正则@regex@5000", "判断值值@conform@3000"};
        PoiExcelUtils poiExcelUtil = new PoiExcelUtils();
        HSSFWorkbook hssfWorkbook = poiExcelUtil.getHSSFWorkbook();
        HSSFSheet hssfSheet = poiExcelUtil.getHSSFSheet(hssfWorkbook, "基线扫描策略");
        poiExcelUtil.writeHeader(hssfWorkbook, hssfSheet, headers, "基线扫描策略");
        writeContentCustom(poiExcelUtil, hssfWorkbook, hssfSheet, headers, this.blineevalMapper.searchAll((String) null, (Integer) null, name_cn, (String) null, DataRule.getRuleWhere(session, "t_bline_policies"), (String) null), 2);
        File f = new File(Constant.WORK_DIR, ObjectUtil.getString(String.valueOf(System.currentTimeMillis()) + ".xls", ""));
        FileOutputStream out = null;
        try {
            try {
                out = FileUtils.openOutputStream(f);
                hssfWorkbook.write(out);
                IOUtils.closeQuietly(out);
                return f;
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(out);
            throw th;
        }
    }

    private void writeContentCustom(PoiExcelUtils poiExcelUtils, HSSFWorkbook hssfWorkbook, HSSFSheet hssfSheet, String[] headers, List<?> dataList, int startIndex) throws Exception {
        Object cellValue;
        int rownum = startIndex;
        HSSFCellStyle cellStyle = poiExcelUtils.createContentCellStyle(hssfWorkbook);
        Map<String, Object> level = new HashMap<>();
        level.put(ReportService.REPORT_STATE_READY, "0【低危】");
        level.put(ReportService.REPORT_STATE_SUCCESS, "1【低危】");
        level.put(ReportService.REPORT_STATE_FAILED, "2【低危】");
        level.put("3", "3【低危】");
        level.put("4", "4【中危】");
        level.put("5", "5【中危】");
        level.put("6", "6【中危】");
        level.put("7", "7【高危】");
        level.put("8", "8【高危】");
        level.put("9", "9【高危】");
        level.put("10", "10【高危】");
        if (!CollectionUtils.isEmpty(dataList)) {
            int size = dataList.size();
            for (int j = 0; j < size; j++) {
                HSSFRow row = hssfSheet.createRow(rownum);
                Map<String, Object> map = (Map) dataList.get(j);
                int len = headers.length;
                for (int i = 0; i < len; i++) {
                    HSSFCell cell = row.createCell(i);
                    String key = ObjectUtil.getString(headers[i].split("@")[1].trim(), "");
                    if (map != null) {
                        cellValue = map.get(key);
                    } else {
                        cellValue = ReflectUtils.getValueOfGetIncludeObjectFeild(dataList.get(j), key);
                    }
                    if (key.equals("level")) {
                        cellValue = level.get(cellValue);
                    }
                    poiExcelUtils.cellValueHandler(cell, cellValue);
                    cell.setCellStyle(cellStyle);
                }
                rownum++;
            }
        }
    }

    public List<Map<String, Object>> getBtype() {
        return this.blineevalMapper.getBtype();
    }
}
